<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>Kahdenna</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>Laajenna</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>Vain %1</translation>
    </message>
</context>
</TS>